-- Shorthand for languages
local en = Turbine.Language.English;
local fr = Turbine.Language.French;
local de = Turbine.Language.German;
local ru = Turbine.Language.Russian;

local text = {};

-- Hello message that appears when plugin is loaded
text.HelloMessage = {
    [en] = "<u><rgb=#DAA520>Reminders v<version>, by Thurallor</rgb></u>";
    [de] = "<u><rgb=#DAA520>Erinnerungen v<version> von Thurallor</rgb></u>";
    [fr] = "<u><rgb=#DAA520>Rappels v<version>, par Thurallor</rgb></u>";
    [ru] = "<u><rgb=#DAA520>Reminders v<version> от Thurallor</rgb></u>"
};
text.TranslationHelpWanted = {
    [en] = "n/a";
    [de] = "Einige Elemente (gekennzeichnet durch †) wurden maschinell übersetzt.  Wenn du uns bei Übersetzungen helfen möchtest, wende dich bitte an Thurallor.";
    [fr] = "Certains éléments (marqués par †) ont été traduits par machine.  Si vous pouvez nous aider avec les traductions, veuillez contacter Thurallor.";
    [ru] = "Некоторые тексты (отмеченные †) были переведены машинным переводом. Если у Вас есть возможность помочь улучшить перевод то, пожалуйста, обратитесь к Thurallor."
};
text.GoodbyeMessage = {
    [en] = "unloaded";
    [de] = "entladen";
    [fr] = "déchargé";
    [ru] = "?"
};
text.PutsPrefix = {
    [en] = "<rgb=#DAA520>Reminders:</rgb> ";
    [de] = "<rgb=#DAA520>Erinnerungen:</rgb> ";
    [fr] = "<rgb=#DAA520>Rappels :</rgb> ";
    [ru] = "<rgb=#DAA520>Reminders:</rgb> "
};
text.ReadingRecipes = {
    [en] = "Reading crafting recipes...";
    [de] = "Handwerksrezepte werden gelesen...";
    [fr] = "Lecture des recettes d'artisanat...";
    [ru] = "?";
};

-- Chat command for controlling Reminders plugin
text.ShellCommand = {
    Command = {
        [en] = "reminders";
        [de] = "erinnerungen";
        [fr] = "rappels";
        [ru] = "reminders"
    };
    SetLoc = {
        [en] = "setloc";
        [de] = "setloc";
        [fr] = "setloc";
        [ru] = "setloc"
    };
    Help = {
        [en] = "help";
        [fr] = "hilfe";
        [de] = "aide";
        [ru] = "help";
    };
    Toggle = {
        [en] = "toggle";
        [de] = "umschalten";
        [fr] = "basculez";
        [ru] = "toggle"
    };
    Window = {
        [en] = "window";
        [de] = "fenster";
        [fr] = "fenêtre";
        [ru] = "window"
    };
    Icon = {
        [en] = "icon";
        [de] = "symbol";
        [fr] = "icône";
        [ru] = "icon"
    };
    ShortHelp = {
        [en] = "Command for controlling the Reminders plugin.";
        [de] = "Befehl zum Kontrollieren des Erinnerungen Plugins.";
        [fr] = "Commandes pour contrôler le plugin Rappels.";
        [ru] = "Команда для управления плагином Reminders."
    };
    LongHelp = {
        [en] = "Reminders commands:\n" ..
               "   /reminders toggle window -- show or hide the main window\n" ..
               "   /reminders toggle icon -- show or hide the icon\n" ..
               "   /reminders setloc -- (used internally by the plugin)";
        [de] = "Erinnerungen Befehle:\n" ..
               "   /erinnerungen umschalten fenster -- das Hauptfenster ein- oder ausblenden\n" ..
               "   /erinnerungen umschalten symbol -- das Symbol ein- oder ausblenden\n" ..
               "   /erinnerungen setloc -- (wird nur pluginintern genutzt)";
        [fr] = "Commandes pour Rappels:\n" ..
               "   /memos basculez fenêtre -- afficher ou masquer la fenêtre principale\n" ..
               "   /memos basculez icône -- afficher ou masquer l'icône\n" ..
               "   /memos setloc -- (utilisé en interne par le plugin)";
        [ru] = "?"
    };
};
                                              
-- Chat parsing strings and regexps
text.Chat = {
    RaidLockDetect1 = {
        [en] = "^(.*) resets in: ([0-9]+)d %- ([0-9]+)h %- ([0-9]+)m%.";
        [de] = "^(.+) wird zurückgesetzt in: ([0-9]+) Tagen %- ([0-9]+) Stunden %- ([0-9]+) Minuten%.";
        [fr] = "^(.+) se réinitialisera dans : ([0-9]+) j %- ([0-9]+) h %- ([0-9]+) min%.";
        [ru] = "?"
    };
    RaidLockDetect2 = {
        [en] = "^(.*) %- Resets in ([0-9]+)d %- ([0-9]+)h %- ([0-9]+)m%.";
        [de] = "^(.+) %- Rückstellung in ([0-9]+) T %- ([0-9]+) Std%. %- ([0-9]+) Min%.%.";
        [fr] = "^(.*) %- Réinitialisé dans ([0-9]+)J %- ([0-9]+)h %- ([0-9]+)m%.";
        [ru] = "?"
    };
    RaidFavoredCompletionsDetect = {
        [en] = "^(.*): You have ([0-9]+) favoured completions? remaining%.";
        [de] = "^(.-): Euch verbleiben ([0-9]+) bevorzugt%(e%) Abschl.-sse?%.";
        [fr] = "^(.*): Vous avez ([0-9]+) achèvements préférés? restant%.";
        [ru] = "?"
    };
    RaidFavoredCompletionsNotes = {
        [en] = "You have [0-9]+ favoured completions? remaining%.";
        [de] = "Euch verbleiben [0-9]+ bevorzugt%(e%) Abschl.-sse?%.";
        [fr] = "Vous avez [0-9]+ achèvements préférés? restant%.";
        [ru] = "?"
    };
    RaidCommonCompletionsDetect = {
        [en] = "^(.*): You have ([0-9]+) completions? remaining%.";
        [de] = "^(.*): Euch verbleiben ([0-9]+) Abschl.-sse?%.";
        [fr] = "^(.*): Vous avez ([0-9]+) achèvements? restant%.";
        [ru] = "?"
    };
    CraftingDetect = {
        [en] = "^You have completed the '(.+)' recipe";
        [de] = "^Ihr habt das Rezept \"(.+)\" fertig gestellt";
        [fr] = "^Vous avez terminé la méthode de préparation '(.+)'";
        [ru] = "?"
    };
    NewRecipeDetect = {
        [en] = "^You have gained knowledge of the '(.+)' recipe for (.+)!";
        [de] = "^Ihr habt das Rezept \"(.+)\" für (.+) erhalten!";
        [fr] = "^Vous avez appris la méthode de préparation '(.+)' pour (.+) !";
        [ru] = "?"
    };
    NewRecipeWarning = {
        [en] = "<rgb=#FF0000>Warning!</rgb> You must reload the plugin before automatic reminders can be created for this new recipe.";
        [de] = "<rgb=#FF0000>Warnung!</rgb> Du musst das Plugin neu laden, bevor automatische Erinnerungen für dieses neue Rezept erstellt werden können.";
        [fr] = "<rgb=#FF0000>Attention !</rgb> Vous devez recharger le plugin avant de pouvoir créer des rappels automatiques pour cette nouvelle recette.";
        [ru] = "?";
    };
    CrateDetect = {
        [en] = "^You open the ([%a ]*crate) and find";
        [de] = "^Ihr öffnet die ([%a%-]*Kiste) und findet";
        [fr] = "^Vous ouvrez la (caisse[%a ]*) et découvrez";
        [ru] = "?"
    };
    QuestBestowDetect = {
        [en] = "^New Quest: (.*)$";
        [de] = "^Neue Aufgabe: (.*)$";
        [fr] = "^Nouvelle quête : (.*)$";
        [ru] = "?"
    };
    QuestCompleteDetect = {
        [en] = "^Completed:\n(.*)\n";
        [de] = "^Abgeschlossen:\n(.*)\n";
        [fr] = "^Terminé :\n(.*)\n";
        [ru] = "?"
    };
    IdentifyTaskQuest = {
        [en] = "Task:";
        [de] = "Auftrag";
        [fr] = "Tâche";
        [ru] = "?"
    };
    ServerTimeCommand = {
        [en] = "/servertime";
        [de] = "/serverzeit";
        [fr] = "/heureserveur";
        [ru] = "?"
    };
    ServerTimeDetect = {
        [en] = "^The current time on the server is ([0-9]+)/([0-9]+) ([0-9]+):([0-9]+) ([AP]M)%.";
        [de] = "^Der Server zeigt die folgende Zeit an: ([0-9]+)%. ([0-9]+)%., ([0-9]+): ([0-9]+) ([AP]M)%.";
        [fr] = "^L'heure actuelle de votre serveur est ([0-9]+)/([0-9]+), ([0-9]+):([0-9]+) ([AP]M)%.";
        [ru] = "?"
    };
	ServerNameCommand = {
        [en] = "/loc";
        [de] = "/pos";
        [fr] = "/emp";
        [ru] = "?"
	};
	ServerNameDetect = {
        [en] = "^You are on.* (%a+) server";
        [de] = "^Ihr seid auf dem Server \".-(%a+)\"";
        [fr] = "^Vous vous trouvez sur.* (%a+), serveur";
        [ru] = "?"
	};
    loc = {
        [en] = ";loc";
        [de] = ";pos";
        [fr] = ";loc";
        [ru] = ";loc"
    };
    ItemRemovedDetect = {
        [en] = "^Item removed.*%: %[(.*)%]%.";
        [de] = "[Ee]ntfernter Gegenstand%: %[(.*)%]%.";
        [fr] = "^Objet retiré.*%: %[(.*)%]%.";
        [ru] = "?";
    };
};

-- Terms relating to time
text.Time = {
    TimeOfDay = {
        [en] = "<h>:<m>";
        [de] = "<h>:<m>";
        [fr] = "<h>h<m>";
        [ru] = "<h>:<m>"
    };
    TimeOfDayRegexp = {
        [en] = "([0-9][0-9]?):([0-9][0-9])";
        [de] = "([0-9][0-9]?):([0-9][0-9])";
        [fr] = "([0-9][0-9]?)h *([0-9][0-9])";
        [ru] = "([0-9][0-9]?):([0-9][0-9])"
    };
    DayOfWeek = {
        Sunday = {
            [en] = "Sunday";
            [de] = "Sonntag";
            [fr] = "Dimanche";
            [ru] = "?"
        };
        Monday = {
            [en] = "Monday";
            [de] = "Montag";
            [fr] = "Lundi";
            [ru] = "?"
        };
        Tuesday = {
            [en] = "Tuesday";
            [de] = "Dienstag";
            [fr] = "Mardi";
            [ru] = "?"
        };
        Wednesday = {
            [en] = "Wednesday";
            [de] = "Mittwoch";
            [fr] = "Mercredi";
            [ru] = "?"
        };
        Thursday = {
            [en] = "Thursday";
            [de] = "Donnerstag";
            [fr] = "Jeudi";
            [ru] = "?"
        };
        Friday = {
            [en] = "Friday";
            [de] = "Freitag";
            [fr] = "Vendredi";
            [ru] = "?"
        };
        Saturday = {
            [en] = "Saturday";
            [de] = "Samstag";
            [fr] = "Samedi";
            [ru] = "?"
        };
        Today = {
            [en] = "Today (<weekday>)";
            [de] = "Heute (<weekday>)";
            [fr] = "Aujourd’hui (<weekday>)";
            [ru] = "?"
        };
        Tomorrow = {
            [en] = "Tomorrow (<weekday>)";
            [de] = "Morgen (<weekday>)";
            [fr] = "Demain (<weekday>)";
            [ru] = "?"
        };
        Next = {
            [en] = "Next <weekday>";
            [de] = "nächster <weekday>";
            [fr] = "<weekday> prochain";
            [ru] = "?"
        };
    };
    Month = {
        January = {
            [en] = "January";
            [de] = "Januar";
            [fr] = "Janvier";
            [ru] = "?"
        };
        February = {
            [en] = "February";
            [de] = "Februar";
            [fr] = "Février";
            [ru] = "?"
        };
        March = {
            [en] = "March";
            [de] = "März";
            [fr] = "Mars";
            [ru] = "?"
        };
        April = {
            [en] = "April";
            [de] = "April";
            [fr] = "Avril";
            [ru] = "?"
        };
        May = {
            [en] = "May";
            [de] = "Mai";
            [fr] = "Mai";
            [ru] = "?"
        };
        June = {
            [en] = "June";
            [de] = "Juni";
            [fr] = "Juin";
            [ru] = "?"
        };
        July = {
            [en] = "July";
            [de] = "Juli";
            [fr] = "Juillet";
            [ru] = "?"
        };
        August = {
            [en] = "August";
            [de] = "August";
            [fr] = "Août";
            [ru] = "?"
        };
        September = {
            [en] = "September";
            [de] = "September";
            [fr] = "Septembre";
            [ru] = "?"
        };
        October = {
            [en] = "October";
            [de] = "Oktober";
            [fr] = "Octobre";
            [ru] = "?"
        };
        November = {
            [en] = "November";
            [de] = "November";
            [fr] = "Novembre";
            [ru] = "?"
        };
        December = {
            [en] = "December";
            [de] = "Dezember";
            [fr] = "Décembre";
            [ru] = "?"
        };
    };
    TimeDisplay = {
        Now = {
            [en] = "Now";
            [de] = "Jetzt";
            [fr] = "Maintenant";
            [ru] = "?"
        };
        NextLogin = {
            [en] = "Next login";
            [de] = "Nächster Login";
            [fr] = "Prochaine connexion";
            [ru] = "?"
        };
        NegativeTime = {
            [en] = "<delay> ago";
            [de] = "vor <delay>";
            [fr] = "il y a <delay>";
            [ru] = "?"
        };
        s = {
            [en] = "<s> seconds";
            [de] = "<s> Sekunden";
            [fr] = "<s> secondes";
            [ru] = "?"
        };
        ms = {
            [en] = "<m>m <s>s";
            [de] = "<m>m <s>s";
            [fr] = "<m>m <s>s";
            [ru] = "?"
        };
        m = {
            [en] = "<m> minutes";
            [de] = "<m> Minuten";
            [fr] = "<m> minutes";
            [ru] = "?"
        };
        hm = {
            [en] = "<h>h <m>m";
            [de] = "<h>S <m>m";
            [fr] = "<h>h <m>m";
            [ru] = "?"
        };
        dhm = {
            [en] = "<d>d <h>h <m>m";
            [de] = "<d>T <h>S <m>m";
            [fr] = "<d>j <h>h <m>m";
            [ru] = "?"
        };
        dh = {
            [en] = "<d>d <h>h";
            [de] = "<d>T <h>S";
            [fr] = "<d>j <h>h";
            [ru] = "?"
        };
        d = {
            [en] = "<d> days";
            [de] = "<d> Tagen";
            [fr] = "<d> jours";
            [ru] = "?"
        };
        dhms = {
            [en] = "<d>d <h>h <m>m <s>s";
            [de] = "<d>T <h>S <m>m <s>s";
            [fr] = "<d>j <h>h <m>m <s>s";
            [ru] = "?"
        };
    };
    TimeInput = {
        Regexp = {
            [en] = "([0-9]+) *([dhms])";
            [de] = "([0-9]+) *([TSms])";
            [fr] = "([0-9]+) *([jhms])";
            [ru] = "([0-9]+) *([dhms])"
        };
        Components = {
            [en] = { d = 24 * 60 * 60; h = 60 * 60; m = 60; s = 1 };
            [de] = { T = 24 * 60 * 60; S = 60 * 60; m = 60; s = 1 };
            [fr] = { j = 24 * 60 * 60; h = 60 * 60; m = 60; s = 1 };
            [ru] = { d = 24 * 60 * 60; h = 60 * 60; m = 60; s = 1 };
        };
    };
    Days = {
        [en] = "days";
        [de] = "Tage";
        [fr] = "jours";
        [ru] = "?"

    };
    Hours = {
        [en] = "hours";
        [de] = "Stunden";
        [fr] = "heures";
        [ru] = "?"

    };
    Minutes = {
        [en] = "minutes";
        [de] = "Minuten";
        [fr] = "minutes";
        [ru] = "?"

    };
    Seconds = {
        [en] = "seconds";
        [de] = "Sekunden";
        [fr] = "secondes";
        [ru] = "?"
    };
    DailyResetTime = {
        [en] = "Daily reset time";
        [de] = "Tägliche Rücksetzzeit";
        [fr] = "Réinitialisation quotidienne";
        [ru] = "?"
    };
    Never = {
        [en] = "Never";
        [de] = "Nie";
        [fr] = "Jamais";
        [ru] = "?"
    };
    AtNextLogin = {
        [en] = "At next login";
        [de] = "Beim nächsten Login";
        [fr] = "A la prochaine connexion";
        [ru] = "?"
    };
};

-- Names that are assigned when something is created
text.Defaults = {
    WindowTitle = {
        [en] = "Reminders";
        [de] = "Erinnerungen";
        [fr] = "Rappels";
        [ru] = "?"
    };
    ReminderDesc = {
        [en] = "New reminder";
        [de] = "Neue Erinnerung";
        [fr] = "Nouveau rappel";
        [ru] = "?"
    };
    TabName = {
        [en] = "New tab";
        [de] = "Neuer Reiter";
        [fr] = "Nouvel onglet";
        [ru] = "?"
    };
    ItineraryTabName = {
        [en] = "Itinerary";
        [de] = "Route";
        [fr] = "Itinéraire";
        [ru] = "?"
    };
    Categories = {
        Other = {
            [en] = "Other";
            [de] = "Andere";
            [fr] = "Divers";
            [ru] = "?"
        };
        Auctions = {
            [en] = "Auctions";
            [de] = "Auktionen";
            [fr] = "Enchères";
            [ru] = "?"
        };
        Crafting = {
            [en] = "Crafting";
            [de] = "Handwerk";
            [fr] = "Artisanat";
            [ru] = "?"
        };
        Crates = {
            [en] = "Ingredient Crates";
            [de] = "Zutatenbündel";
            [fr] = "Caisses d’ingrédients";
            [ru] = "?"
        };
        Instances = {
            [en] = "Instances";
            [de] = "Instanzen";
            [fr] = "Instances";
            [ru] = "?"
        };
        Quests = {
            [en] = "Quests";
            [de] = "Aufgaben";
            [fr] = "Quêtes";
            [ru] = "?"
        };
        Tasks = {
            [en] = "Tasks";
            [de] = "Aufträge";
            [fr] = "Tâches";
            [ru] = "?"
        };
    };
    CategoryName = {
        [en] = "New category";
        [de] = "Neue Kategorie";
        [fr] = "Nouvelle catégorie";
        [ru] = "?"
    };
    CrateName = {
        [en] = "Unknown crate";
        [de] = "unbekannte Kiste";
        [fr] = "Caisse inconnue";
        [ru] = "?"
    };
    CrateReminderDesc = {
        [en] = "Open <cratename>";
        [de] = "Öffne <cratename>";
        [fr] = "Ouvrir <cratename>";
        [ru] = "?"
    };
    TaskReminderDesc = {
        [en] = "Do daily “tasks”";
        [de] = "erledige tägliche „Aufträge“";
        [fr] = "Faire les « tâches »";
        [ru] = "?"
    };
    Professions = {
        ["1"] = {
            [en] = "Metalsmith";
            [de] = "Schmied";
            [fr] = "Ferronnier";
            [ru] = "?"
        };
        ["2"] = {
            [en] = "Forester";
            [de] = "Förster";
            [fr] = "Forestier";
            [ru] = "?"
        };
        ["3"] = {
            [en] = "Scholar";
            [de] = "Gelehrter";
            [fr] = "Erudit";
            [ru] = "?"
        };
        ["4"] = {
            [en] = "Jeweller";
            [de] = "Goldschmied";
            [fr] = "Bijoutier";
            [ru] = "?"
        };
        ["5"] = {
            [en] = "Tailor";
            [de] = "Schneider";
            [fr] = "Tailleur";
            [ru] = "?"
        };
        ["6"] = {
            [en] = "Weaponsmith";
            [de] = "Waffenschmied";
            [fr] = "Fabricant d'armes";
            [ru] = "?"
        };
        ["7"] = {
            [en] = "Prospector";
            [de] = "Entdecker";
            [fr] = "Prospecteur";
            [ru] = "?"
        };
        ["8"] = {
            [en] = "Woodworker";
            [de] = "Drechsler";
            [fr] = "Menuisier";
            [ru] = "?"
        };
        ["9"] =  {
            [en] = "Farmer";
            [de] = "Bauer";
            [fr] = "Fermier";
            [ru] = "?"
        };
        ["10"] = {
            [en] = "Cook";
            [de] = "Koch";
            [fr] = "Cuisinier";
            [ru] = "?"
        };
    };
    CraftingTiers = {
        ["1"] = {
            [en] = "Apprentice";
            [de] = "Lehrling";
            [fr] = "Apprenti";
            [ru] = "?"
        };
        ["2"] = {
            [en] = "Journeyman";
            [de] = "Geselle";
            [fr] = "Compagnon";
            [ru] = "?"
        };
        ["3"] = {
            [en] = "Expert";
            [de] = "Experte";
            [fr] = "Expert";
            [ru] = "?"
        };
        ["4"] = {
            [en] = "Artisan";
            [de] = "Virtuose";
            [fr] = "Artisan";
            [ru] = "?"
        };
        ["5"] = {
            [en] = "Master";
            [de] = "Meister";
            [fr] = "Maître";
            [ru] = "?"
        };
        ["6"] = {
            [en] = "Supreme";
            [de] = "Überragend";
            [fr] = "Suprême";
            [ru] = "?"
        };
        ["7"] = {
            [en] = "Westfold";
            [de] = "Westfold";
            [fr] = "Oeustfolde";
            [ru] = "?"
        };
        ["8"] = {
            [en] = "Eastemnet";
            [de] = "Ost-Emnet";
            [fr] = "Estemnet";
            [ru] = "?"
        };
        ["9"] = {
            [en] = "Westemnet";
            [de] = "West-Emnet";
            [fr] = "Ouestemnet";
            [ru] = "?"
        };
        ["10"] = {
            [en] = "Anórien";
            [de] = "Anórien";
            [fr] = "Anórien";
            [ru] = "?"
        };
        ["11"] = {
            [en] = "Doomfold";
            [de] = "Unheilskluft";
            [fr] = "Folde du Destin";
            [ru] = "?"
        };
        ["12"] = {
            [en] = "Ironfold";
            [de] = "Eisenbruch";
            [fr] = "Crevasse de fer";
            [ru] = "?"
        };
        ["13"] = {
            [en] = "Minas Ithil";
            [de] = "Minas Ithil";
            [fr] = "Minas Ithil";
            [ru] = "?"
        };
        ["14"] = {
            [en] = "Gundabad";
            [de] = "Gundabad";
            [fr] = "Gundabad";
            [ru] = "?"
        };
    };
};

-- Main window
text.MainWindow = {
    AddNewReminder = {
        [en] = "Add new reminder";
        [de] = "Neue Erinnerung hinzufügen";
        [fr] = "Ajouter un rappel";
        [ru] = "?"
    };
    CurrentScope = {
        character = {
            [en] = "Filter: Current character";
            [de] = "Filter: Aktueller Charakter";
            [fr] = "Filtre : caractère actuel";
            [ru] = "?";
        };
        server = {
            [en] = "Filter: Current server";
            [de] = "Filter: Aktueller Server";
            [fr] = "Filtre : serveur actuel";
            [ru] = "?";
        };
        account = {
            [en] = "Filter: All characters on all servers";
            [de] = "Filter: Alle Charaktere auf allen Servern";
            [fr] = "Filtre : tous les caractères sur tous les serveurs";
            [ru] = "?";
        };
    };
    OpenOptionsPanel = {
        [en] = "Open the options panel";
        [de] = "Das Einstellungsmenü öffnen";
        [fr] = "Ouvrir le panneau des options";
        [ru] = "?"
    };
    ColumnHeadings = {
        Checkbox = {
            [en] = "Checkbox";
            [de] = "Kontrollkästchen";
            [fr] = "Case à cocher";
            [ru] = "?"
        };
        Description = {
            [en] = "Description";
            [de] = "Beschreibung";
            [fr] = "Description";
            [ru] = "?"
        };
        Location = {
            [en] = "Location";
            [de] = "Position";
            [fr] = "Coordonnées";
            [ru] = "?"
        };
        Distance = {
            [en] = "Distance";
            [de] = "Entfernung";
            [fr] = "Distance";
            [ru] = "?"
        };
        Category = {
            [en] = "Category";
            [de] = "Kategorie";
            [fr] = "Catégorie";
            [ru] = "?"
        };
        Character = {
            [en] = "Character";
            [de] = "Charakter";
            [fr] = "Personnage";
            [ru] = "?"
        };
        Server = {
            [en] = "Server";
            [de] = "Server";
            [fr] = "Serveur";
            [ru] = "?"
        };
        Time = {
            [en] = "Time";
            [de] = "Zeit";
            [fr] = "Délai";
            [ru] = "?"
        };
        NextReset = {
            [en] = "Next Reset";
            [de] = "Nächste Zurücksetzung";
            [fr] = "Prochaine réinitialisation";
            [ru] = "?"
        };
        Location = {
            [en] = "Location";
            [de] = "Lage";
            [fr] = "Coordonnées";
            [ru] = "?"
        };
        Notes = {
            [en] = "Notes";
            [de] = "Notizen";
            [fr] = "Notes";
            [ru] = "?";
        };
    };
    DeleteThisReminder = {
        [en] = "Delete this reminder";
        [de] = "Diese Erinnerung löschen";
        [fr] = "Supprimer ce rappel";
        [ru] = "?"
    };
    AutomaticReminderSettings = {
        [en] = "This reminder was automatically updated <interval> ago.  Click here to see why.";
        [de] = "Diese Erinnerung wurde automatisch vor <interval> aktualisiert. Hier klicken, um zu sehen warum.";
        [fr] = "Ce rappel a été automatiquement mis à jour il y a <interval>. Cliquez ici pour voir pourquoi";
        [ru] = "?";
    };
    DetectLocation = {
        [en] = "Detect your current location";
        [de] = "   aktuelle Position ermitteln   ";
        [fr] = "Détecter votre emplacement actuel";
        [ru] = "?"
    };
    CalculateDistances = {
        [en] = "Calculate distances from your current location";
        [de] = "Entfernungen vom aktuellen Standort berechnen";
        [fr] = "Calculer la distance depuis votre position actuelle";
        [ru] = "?"
    };
    SetWaypointTarget = {
        [en] = "Use ‘‘Waypoint’’ to find this location";
        [de] = "‚‚Waypoint‘‘ (Wegpunkt) nutzen, um diesen Ort zu finden";
        [fr] = "Utiliser « Waypoint » pour trouver cet emplacement";
        [ru] = "?"
    };
    TabContextMenu = {
        CreateTab = {
            [en] = "Create new tab";
            [de] = "Neuen Reiter erstellen";
            [fr] = "Nouvel onglet";
            [ru] = "?"
        };
        CreateItinerary = {
            [en] = "Create itinerary";
            [de] = "Route erstellen";
            [fr] = "Nouvel itinéraire";
            [ru] = "?"
        };
        RenameTab = {
            [en] = "Rename this tab";
            [de] = "Reiter umbenennen";
            [fr] = "Renommer l'onglet";
            [ru] = "?"
        };
        Color = {
            [en] = "Color...";
            [de] = "Farbe...";
            [fr] = "Couleur...";
            [ru] = "Цвет..."
        };
        CloneTab = {
            [en] = "Clone this tab";
            [de] = "Diesen Reiter kopieren";
            [fr] = "Dupliquer l'onglet";
            [ru] = "?"
        };
        MergeWithOtherTab = {
            [en] = "Merge this tab with";
            [de] = "Diesen Reiter verschmelzen mit";
            [fr] = "Fusionner l'onglet avec.....";
            [ru] = "?"
        };
        DeleteTab = {
            [en] = "Delete this tab";
            [de] = "Diesen Reiter löschen";
            [fr] = "Supprimer l'onglet";
            [ru] = "?"
        };
        OtherOptions = {
            [en] = "Other options...";
            [de] = "Weitere Optionen...";
            [fr] = "Autres options...";
            [ru] = "?"
        };
    };
    MoreTabs = {
        [en] = "More tabs...";
        [de] = "Mehr Reiter...";
        [fr] = "Plus d'onglets...";
        [ru] = "?"
    };
    EventContextMenu = {
        MoveToOtherTab = {
            [en] = "Move to other tab";
            [de] = "In einen anderen Reiter schieben";
            [fr] = "Déplacer vers un autre onglet";
            [ru] = "?"
        };
        CopyToOtherTab = {
            [en] = "Copy to other tab";
            [de] = "In einen anderen Reiter kopieren";
            [fr] = "Copier dans un autre onglet";
            [ru] = "?"
        };
        Clone = {
            [en] = "Clone";
            [de] = "Kopieren";
            [fr] = "Dupliquer";
            [ru] = "?"
        };
        Delete = {
            [en] = "Delete";
            [de] = "Löschen";
            [fr] = "Supprimer";
            [ru] = "?"
        };
        AddDay = {
            [en] = "Add 24 hours";
            [de] = "24 Stunden hinzufügen";
            [fr] = "Ajouter 24 heures";
            [ru] = "?"
        };
        AddWeek = {
            [en] = "Add 1 week";
            [de] = "1 Woche hinzufügen";
            [fr] = "Ajouter 1 semaine";
            [ru] = "?"
        };
    };
    CharacterOnServer = {
        [en] = "<name> on <server>";
        [de] = "<name> auf <server>";
        [fr] = "<name> sur <server>";
        [ru] = "?";
    };
    CurrentServer = {
        [en] = "<server> (current)";
        [de] = "<server> (aktuell)";
        [fr] = "<server> (actuel)";
        [ru] = "?";
	};
    NoTabsDisplayed = {
        [en] = "(No tabs displayed)";
        [de] = "(Keine Reiter angezeigt†)";
        [fr] = "(Aucun onglet affiché†)";
        [ru] = "?";
    };
};

-- Messages that "bubble up" from the icon
text.Cascade = {
    ReminderCreated = {
        [en] = "Created reminder: ";
        [de] = "Erinnerung erstellt: ";
        [fr] = "Rappel créé: ";
        [ru] = "?"
    };
    ReminderUpdated = {
        [en] = "Updated reminder: ";
        [de] = "Erinnerung aktualisiert: ";
        [fr] = "Rappel mis à jour: ";
        [ru] = "?"
    };
    Example = {
        [en] = "Example of a bubble notification";
        [de] = "Beispiel für eine Blasenbenachrichtigung";
        [fr] = "Exemple de notification par bulle";
        [ru] = "?"
    };
};

text.ConfirmDialog = {
    AreYouSure = {
        [en] = "Are you sure?";
        [de] = "Bist du sicher?";
        [fr] = "Vous êtes sûr ?";
        [ru] = "?"
    };
    Yes = {
        [en] = "Yes";
        [de] = "Ja";
        [fr] = "Oui";
        [ru] = "?"
    };
    No = {
        [en] = "No";
        [de] = "Nein";
        [fr] = "Non";
        [ru] = "?"
    };
    AskBeforeDeleting = {
        [en] = "Always ask before deleting things";
        [de] = "Vor dem Löschen immer fragen";
        [fr] = "Toujours demandez avant de supprimer quelque chose";
        [ru] = "?"
    };
    AskBeforeDeletingWidth = {
        [en] = 250;
        [de] = 280;
        [fr] = 300;
        [ru] = 200
    };
};

-- When migrating from old server-specific settings to new account-wide settings
text.MigrateDialog = {
    Title = {
        [en] = "Welcome to Reminders v<version>";
        [de] = "Willkommen bei Erinnerungen v<version>";
        [fr] = "Bienvenue dans Rappels v<version>";
        [ru] = "?"
    };
    Width = {
        [en] = 500;
        [de] = 500;
        [fr] = 500;
        [ru] = 500;
    };
    Intro = {
        [en] = "This plugin now supports multiple servers: You can now see reminders for all servers simultaneously.  However, you will not be able to see reminders for other servers until you have logged into those servers.";
        [de] = "Dieses Plugin untertützt jetzt mehrere Server: Du kannst jetzt Erinnerungen führ mehrere Server gleichzeitig sehen. Du wirst die Erinnerungen für andere Server jedoch erst sehen, nachdem du dich dort angemeldet hast.";
        [fr] = "Ce plugin prend désormais en charge plusieurs serveurs : vous pouvez désormais voir les rappels pour tous les serveurs simultanément. Cependant, vous ne pourrez pas voir les rappels pour d'autres serveurs tant que vous ne vous serez pas connecté à ces serveurs.";
        [ru] = "?"
    };
    IntroLines = {
        [en] = 4;
        [de] = 4;
        [fr] = 5;
        [ru] = 4;
    };
    WhichServer = {
        [en] = "This is the first time you have logged into this server since upgrading the plugin.  Which server are you currently logged in on?";
        [de] = "Dies ist deine erste Anmeldung auf diesem Server seit du das Plugin geupdated hast.  Auf welchem Server bist du gerade angemeldet?";
        [fr] = "C'est la première fois que vous vous connectez à ce serveur depuis la mise à niveau du plugin.  Sur quel serveur êtes-vous actuellement connecté?";
        [ru] = "?"
    };
    WhichServerLines = {
        [en] = 2;
        [de] = 2;
        [fr] = 3;
        [ru] = 3;
    };
    ExistingSettings = {
        [en] = "Your existing data file for <server> is located at:";
        [de] = "Die Datei mit deinen existenten Daten für <server> befindet sich in:";
        [fr] = "Votre fichier de données existantes pour <server> se trouve à l'adresse :";
        [ru] = "?"
    };
    ExistingSettingsLines = {
        [en] = 1;
        [de] = 1;
        [fr] = 2;
        [ru] = 1;
    };
    
    BackupOldSettings = {
        [en] = "This will be copied to a backup file at:";
        [de] = "Diese Daten werden in eine Sicherungsdatei kopiert, in:";
        [fr] = "Cela sera copié dans un fichier de sauvegarde à";
        [ru] = "?"
    };
    BackupOldSettingsLines = {
        [en] = 1;
        [de] = 1;
        [fr] = 1;
        [ru] = 1;
    };
    CreateNewSettings = {
        [en] = "Then, it will be merged into your new account-wide data file, at:";
        [de] = "Danach werden sie in einer neue kontoweite Datei zusammengeführt, in:";
        [fr] = "Ensuite, il sera fusionné dans votre nouveau fichier de données à l'échelle du compte, à l'adresse :";
        [ru] = "?"
    };
    CreateNewSettingsLines = {
        [en] = 1;
        [de] = 2;
        [fr] = 2;
        [ru] = 2;
    };
    Ok = {
        [en] = "Ok";
        [de] = "Ok";
        [fr] = "Ok";
        [ru] = "?"
    };
    AfterYouClickOK = {
        [en] = "After you click OK, please unload and reload the plugin.";
        [de] = "Bitte entlade das Plugin und lade es neu, nachdem du auf OK geklickt hast.";
        [fr] = "Après avoir cliqué sur OK, veuillez décharger et recharger le plugin.";
        [ru] = "?"
    };
    AfterYouClickOKLines = {
        [en] = 1;
        [de] = 2;
        [fr] = 1;
        [ru] = 2;
    };
};

-- Small dialog for renaming a tab
text.RenameTabDialog = {
    Title = {
        [en] = "Rename";
        [de] = "Umbenennen";
        [fr] = "Renommer";
        [ru] = "?"
    };
};

-- Dialog for creating a new itinerary
text.ItineraryDialog = {
    Title = {
        [en] = "New itinerary";
        [de] = "Neue Route";
        [fr] = "Nouvel itinéraire";
        [ru] = "?"
    };
    Instructions = {
        [en] = "Please paste a list of locations in the box below.  You may include any descriptive text.  Each line will be searched for a set of coordinates, such as “25.5S, 91.0W”.";
        [de] = "Bitte füge eine Liste von Orten in das folgende Feld ein: Du kannst jeden beschreibenden Text einbeziehen. Jede Zeile wird nach einem Muster von Koordinaten durchsucht, z.B. „25.5S, 91.0W“.";
        [fr] = "Veuillez coller une liste de coordonnées dans le champ ci-dessous. Vous devriez ajouter un description. Chaque ligne représente une coordonnée recherchée telle que « 25.5S, 91.0W ».";
        [ru] = "?"
    };
    CreateButton = {
        [en] = "Create";
        [de] = "Erzeugen";
        [fr] = "Créer";
        [ru] = "?"
    };
    CreateButtonWidth = {
        [en] = "75";
        [de] = "80";
        [fr] = "65";
        [ru] = "75"
    };
    FoundLocations = {
        [en] = "Found <num> locations.";
        [de] = "<num> Orte gefunden";
        [fr] = "<num> emplacements trouvés";
        [ru] = "?"
    };
};

-- "Postpone" icon behavior setting dialog
text.PostponeTimeDialog = {
    Title = {
        [en] = "Reset method";
        [de] = "Methode zurücksetzen";
        [fr] = "Méthode de réinitialisation";
        [ru] = "?"
    };
    Instructions = {
        [en] = "Please select the action for the reset button (<icon>) for this reminder:";
        [de] = "Bitte eine Aktion für die Zurücksetzen-Taste (<icon>) für diese Erinnerung auswählen:";
        [fr] = "Veuillez sélectionner l'action du bouton de réinitialisation (<icon>) pour ce rappel:";
        [ru] = "?"
    };
    DeferUntilNextLogin = {
        [en] = "Defer it until next login";
        [de] = "Bis zur nächsten Anmeldung verschieben";
        [fr] = "Reportez-le jusqu'à la prochaine connexion";
        [ru] = "?"
    };
    PostponeFor = {
        [en] = "Postpone the reminder for:";
        [de] = "Die Erinnerung verschieben um:";
        [fr] = "Reporter le rappel de :";
        [ru] = "?"
    };
    FromCurrentTime = {
        [en] = "from the current time";
        [de] = "ab der aktuellen Uhrzeit";
        [fr] = "à partir de l'heure actuelle";
        [ru] = "?"
    };
    FromPreviousExpiration = {
        [en] = "from the previous expiration time";
        [de] = "ab der vorherigen Verfallszeit";
        [fr] = "à partir de la date d'expiration précédente";
        [ru] = "?"
    };
    DeferUntilDailyResetTime = {
        [en] = "Defer it until daily server reset time (3 AM server time)";
        [de] = "Aufschieben bis zum Zeitpunkt des täglichen Server-Resets (03:00 Uhr Serverzeit)";
        [fr] = "Reportez-le jusqu'à l'heure de réinitialisation quotidienne du serveur (03h00, heure du serveur)";
        [ru] = "?"
    };
    DeferUntilScheduledResetTime = {
        [en] = "Defer it until the next scheduled reset time";
        [de] = "Auf die nächste geplante Rücksetzzeit verschieben";
        [fr] = "Reporter à l'heure de réinitialisation programmée suivante";
        [ru] = "?"
    };
    TurnOffTimer = {
        [en] = "Turn off the timer";
        [de] = "Timer ausschalten";
        [fr] = "Éteignez le minuteur";
        [ru] = "?"
    };
    Tooltip = {
        DelayFromNow = {
            [en] = "Postpone this until <delay> from now";
            [de] = "Um <delay> ab jetzt verschieben";
            [fr] = "Reporter cela à <delay> à partir de maintenant";
            [ru] = "?"
        };
        DelayFromExpiration = {
            [en] = "Postpone this until <interval> after the previous expiration (<delay> from now)";
            [de] = "Verzögerung bis <interval> nach dem früheren Ablaufdatum (in <delay>)";
            [fr] = "Repousser jusqu'à <interval> après l'heure d'expiration précédente (<delay> à partir de maintenant)";
            [ru] = "?"
        };
        AtNextLogin = {
            [en] = "Defer this until next login";
            [de] = "Bis zum nächsten Login verschieben";
            [fr] = "Repousser jusqu'à la prochaine connexion";
            [ru] = "?"
        };
        DailyResetTime = {
            [en] = "Postpone this until daily server reset time (<delay> from now)";
            [de] = "Bis zum täglichen Server-Reset (in <delay>) verschieben";
            [fr] = "Repousser à la réinitialisation quotidienne du serveur (<delay> à partir de maintenant)";
            [ru] = "?"
        };
        ScheduledResetTime = {
            [en] = "Defer this until the next scheduled reset time (<delay> from now)";
            [de] = "Auf die nächste geplante Rücksetzzeit (in <delay>) verschieben";
            [fr] = "Reporter à la prochaine heure de réinitialisation programmée (<delay> à partir de maintenant)";
            [ru] = "?"
        };
        Never = {
            [en] = "Turn off the timer";
            [de] = "Timer ausschalten";
            [fr] = "Éteignez le minuteur";
            [ru] = "?"
        };
        Forever = {
        };
    };
    TooltipRightClick = {
        [en] = "(Right-click for other options)";
        [de] = "(Rechts-Klick für weitere Optionen)";
        [fr] = "(Clic-droit pour d'autres options)";
        [ru] = "?"
    };
    Postpone = {
        [en] = "Postpone";
        [de] = "Verschieben";
        [fr] = "Décaler";
        [ru] = "?"
    };
    FromNow = {
        [en] = "from now";
        [de] = "ab jetzt";
        [fr] = "à partir de maintenant";
        [ru] = "?"
    };
    FromExpiration = {
        [en] = "from expiration";
        [de] = "nach Ablauf";
        [fr] = "après l'expiration";
        [ru] = "?"
    };
};

-- "Expiration Time" dialog
text.ExpireTimeDialog = {
    Title = {
        [en] = "Expiration Time";
        [de] = "Ablaufzeit";
        [fr] = "Délai d’expiration";
        [ru] = "?"
    };
    DelayFromNow = {
        [en] = "Delay from now";
        [de] = "Verzögerung ab jetzt";
        [fr] = "Alerter dans";
        [ru] = "?"
    };
    TimeThisWeek = {
        [en] = "Specific time this week";
        [de] = "Bestimmte Zeit in dieser Woche";
        [fr] = "Alerter cette semaine";
        [ru] = "?"
    };
    DateAndTime = {
        [en] = "Specific date and time";
        [de] = "Bestimmtes Datum und Zeit";
        [fr] = "Alerter à un moment spécifique";
        [ru] = "?"
    };
    AtTime = {
            [en] = "at";
            [de] = "um";
            [fr] = "à";
            [ru] = "?"
    };
    HourMinuteSeparator = {
        [en] = ":";
        [de] = ":";
        [fr] = "h";
        [ru] = ":"
    };
    HourMinuteSeparatorAdjust = {
        [en] = 2;
        [de] = 2;
        [fr] = 1;
        [ru] = 0
    };
    OClock = {
        [en] = "o'clock";
        [de] = "Uhr";
        [fr] = "";
        [ru] = "?"
    };
    Ok = {
        [en] = "Ok";
        [de] = "Ok";
        [fr] = "Ok";
        [ru] = "?"
    };
    NotOkTooltip = {
        [en] = "The selected time has already passed.";
        [de] = "Die gewählte Uhrzeit ist bereits vorbei";
        [fr] = "L'alerte ne peut pas être réglée à un moment déjà passé.";
        [ru] = "?"
    };
    Cancel = {
        [en] = "Cancel";
        [de] = "Abbrechen";
        [fr] = "Annuler";
        [ru] = "?"
    };
    CancelWidth = {
        [en] = 80;
        [de] = 100;
        [fr] = 90;
        [ru] = 90
    };
};

-- "Reset Times" dialog
text.ResetTimesDialog = {
    Title = {
        [en] = "Reset times";
        [de] = "Rücksetzzeiten";
        [fr] = "Temps de réinitialisation";
        [ru] = "?"
    };
    DeleteThisResetTime = {
        [en] = "Delete this reset time from the list";
        [de] = "Diese Rücksetzzeit aus der Liste entfernen.";
        [fr] = "Supprimer ce temps de réinitialisation de la liste";
        [ru] = "?"
    };
    NotOkTooltip = {
        [en] = "All times must be between 00:00 and 23:59.";
        [de] = "Alle Zeiten müssen zwischen 00:00 und 23:59 Uhr liegen.";
        [fr] = "Toutes les heures doivent se situer entre 00h00 et 23h59.";
        [ru] = "?"
    };
    EveryDay = {
        [en] = "Every day";
        [de] = "Jeden Tag";
        [fr] = "Tous les jours";
        [ru] = "?"
    };
    At = {
        [en] = "at";
        [de] = "um";
        [fr] = "à";
        [ru] = "?"
    };
    OclockServerTime = {
        [en] = "o'clock server time";
        [de] = "Uhr Serverzeit";
        [fr] = "Heure du serveur";
    }
};

-- "Quest Repeated" dialog
text.QuestRepeatedDialog = {
    Title = {
        [en] = "Repeated Quest";
        [de] = "Wiederhole Aufgabe";
        [fr] = "Quête répétable";
        [ru] = "?"
    };
    Question = {
        [en] = "You've completed this quest before, <elapsed> ago.  Would you like to create a reminder to redo it, each time you complete it?";
        [de] = "Du hast diese Aufgabe schon vor <elapsed> abgeschlossen. Möchtest du eine neue Erinnerung erstellen, um sie jedes Mal zu wiederholen, nachdem du sie abgeschlossen hast?";
        [fr] = "Vous avez accompli cette quête il y a <elapsed>. Voulez-vous générer un rappel pour la refaire à chaque fois que vous l'accomplissez ?";
        [ru] = "?"
    };
    QuestionLines = {
        [en] = 2;
        [de] = 3;
        [fr] = 2;
        [ru] = 2
    };
    Yes = {
        [en] = " Yes";
        [de] = " Ja";
        [fr] = " Oui";
        [ru] = "?"
    };
    No = {
        [en] = " No";
        [de] = " Nein";
        [fr] = " Non";
        [ru] = "?"
    };
    Options = {
        [en] = "Customize";
        [de] = "Anpassen";
        [fr] = "Personnaliser";
        [ru] = "?"
    };
    ColumnWidth = {
        [en] = 100;
        [de] = 116;
        [fr] = 116;
        [ru] = 116;
    };
    GetCurrentLocation = {
        [en] = "Detect";
        [de] = "Erkennen";
        [fr] = "Détecter";
        [ru] = "?"
    };
    GetCurrentLocationWidth = {
        [en] = 80;
        [de] = 80;
        [fr] = 80;
        [ru] = 80
    };
    Tab = {
        [en] = "Tab";
        [de] = "Reiter";
        [fr] = "Onglet";
        [ru] = "?"
    };
    QuestCanBeRepeated = {
        [en] = "Quest can be repeated";
        [de] = "Aufgabe kann wiederholt werden";
        [fr] = "La quête peut être répétée";
        [ru] = "?"
    };
    AfterCooldownTime = {
        [en] = " after cooldown time:";
        [de] = " nach der Abklingzeit:";
        [fr] = " au bout de:";
        [ru] = "?"
    };
    WhenItResets = {
        [en] = " when it resets:";
        [de] = " wenn sie zurückgesetzt wird:";
        [fr] = " quand il se réinitialisera:";
        [ru] = "?"
    };
    RemindMe = {
        [en] = "Remind me";
        [de] = "Erinnere mich";
        [fr] = "Me le rappeller";
        [ru] = "?"
    };
    RemindMeWidth = {
        [en] = 100;
        [de] = 110;
        [fr] = 125;
        [ru] = 100
    };
    RemindMeNow = {
        [en] = "Now";
        [de] = "Jetzt";
        [fr] = "Maintenant";
        [ru] = "?"
    };
    RemindMeNowTooltip = {
        [en] = "If this box is ticked, the reminder will be created immediately after you click ‘‘Remind me’’.\nOtherwise, the reminder will be created the next time the quest is completed.";
        [de] = "Wenn dieses Kontrollkästchen aktiviert ist, wird die Erinnerung sofort erstellt, nachdem du auf ,,Erinnere mich‘‘ geklickt hast.\nAndernfalls wird die Erinnerung erstellt, wenn die Aufgabe das nächste Mal abgeschlossen wird.";
        [fr] = "Si cette case est cochée, le rappel sera créé immédiatement après que vous aurez cliqué sur ‹‹ Me le rappeller ››.\nSinon, le rappel sera créé la prochaine fois que la quête sera terminée.";
        [ru] = "?";
    };
    DontRemindMe = {
        [en] = "Don't remind me";
        [de] = "Keine Erinnerung";
        [fr] = "Ne pas me le rappeller";
        [ru] = "?"
    };
    DontRemindMeWidth = {
        [en] = 130;
        [de] = 130;
        [fr] = 175;
        [ru] = 130
    };
};

-- "Raid Lock" dialog
text.RaidLockDialog = {
    Title = {
        [en] = "Raid/Chest Lock";
        [de] = "Schlachtzug-/Lootsperre";
        [fr] = "Raid/Verrouillage du coffre";
        [ru] = "?"
    };
    Question = {
        [en] = "Would you like to create a reminder for this raid/chest, each time you complete it?";
        [de] = "Möchtest du eine Erinnerung für diesen Schlachtzug/diese Truhe erstellen (nach jedem Abschluss)?";
        [fr] = "Souhaitez-vous créer un rappel pour ce raid/coffre à chaque fois que vous le terminez ?";
        [ru] = "?"
    };
    QuestionLines = {
        [en] = 1;
        [de] = 2;
        [fr] = 2;
        [ru] = 1
    };
    Yes = {
        [en] = " Yes";
        [de] = " Ja";
        [fr] = " Oui";
        [ru] = "?"
    };
    No = {
        [en] = " No";
        [de] = " Nein";
        [fr] = " Non";
        [ru] = "?"
    };
    Options = {
        [en] = "Customize";
        [de] = "Anpassen";
        [fr] = "Personnaliser";
        [ru] = "?"
    };
    ColumnWidth = {
        [en] = 100;
        [de] = 116;
        [fr] = 116;
        [ru] = 116;
    };
    GetCurrentLocation = {
        [en] = "Detect";
        [de] = "Erkennen";
        [fr] = "Détecter";
        [ru] = "?"
    };
    GetCurrentLocationWidth = {
        [en] = 80;
        [de] = 80;
        [fr] = 80;
        [ru] = 80
    };
    Tab = {
        [en] = "Tab";
        [de] = "Reiter";
        [fr] = "Onglet";
        [ru] = "?"
    };
    LockResetsAt = {
        [en] = "When does this raid/chest lock reset?";
        [de] = "Wann wird diese Schlachtzug-/Lootsperre zurückgesetzt?";
        [fr] = "Quand ce raid/verrouillage de coffre se réinitialise-t-il ?";
        [ru] = "?"
    };
    RemindMe = {
        [en] = "Remind me";
        [de] = "Erinnere mich";
        [fr] = "Me le rappeller";
        [ru] = "?"
    };
    RemindMeWidth = {
        [en] = 100;
        [de] = 110;
        [fr] = 125;
        [ru] = 100
    };
    RemindMeNow = {
        [en] = "Now";
        [de] = "Jetzt";
        [fr] = "Maintenant";
        [ru] = "?"
    };
    RemindMeNowTooltip = {
        [en] = "If this box is ticked, the reminder will be created immediately after you click ‘‘Remind me’’.\nOtherwise, the reminder will be created the next time the lock status changes.";
        [de] = "Wenn dieses Kontrollkästchen aktiviert ist, wird die Erinnerung sofort erstellt, nachdem du auf ,,Erinnere mich‘‘ geklickt hast.\nAndernfalls wird die Erinnerung bei der nächsten Änderung des Sperrstatus erstellt.";
        [fr] = "Si cette case est cochée, le rappel sera créé immédiatement après que vous aurez cliqué sur ‹‹ Me le rappeller ››.\nSinon, le rappel sera créé la prochaine fois que le statut du verrouillage changera.";
        [ru] = "?";
    };
    DontRemindMe = {
        [en] = "Don't remind me";
        [de] = "Keine Erinnerung";
        [fr] = "Ne pas me le rappeller";
        [ru] = "?"
    };
    DontRemindMeWidth = {
        [en] = 130;
        [de] = 130;
        [fr] = 175;
        [ru] = 130
    };
};

-- Strings used in the Options panel in the Plugin Manager
text.OptionsPanel = {
    Title = {
        [en] = "Reminders: Settings";
        [de] = "Erinnerungen: Einstellungen";
        [fr] = "Rappels : Options";
        [ru] = "?"
    };
    GlobalTab = {
        TabName = {
            [en] = "Global";
            [de] = "Global";
            [fr] = "Global";
            [ru] = "?"
        };
        General = {
            [en] = "General";
            [de] = "Allgemein";
            [fr] = "Général";
            [ru] = "?"
        };
        Language = {
            [en] = "Language";
            [de] = "Sprache";
            [fr] = "Langue";
            [ru] = "Язык"
        };
        English = {
            [en] = "English";
            [de] = "English (Englisch)";
            [fr] = "English (Anglais)";
            [ru] = "English (Английский)"
        };
        German = {
            [en] = "Deutsch (German)";
            [de] = "Deutsch";
            [fr] = "Deutsch (Allemand)";
            [ru] = "Deutsch (Немецкий)"
        };
        French = {
            [en] = "Français (French)";
            [de] = "Français (Französisch)";
            [fr] = "Français";
            [ru] = "Français (Французский)"
        };
        Russian = {
            [en] = "Русский (Russian)";
            [de] = "Русский (Russisch)";
            [fr] = "Русский (Russie)";
            [ru] = "Русский"
        };
        PauseDuringCombat = {
            [en] = "Pause the plugin during combat";
            [de] = "Plugin während des Kampfes stoppen";
            [fr] = "Mettre le plugin en veille lors des combats";
            [ru] = "?"
        };
        ReuseExpiredReminders = {
            [en] = "Automatic reminders should replace existing reminders (auto refresh)";
            [de] = "Automatische Erinnerungen sollen bereits bestehende ersetzen (automatische Erneuerung)";
            [fr] = "Les rappels automatiques remplacent les rappels équivalents existants (rafraîchissement automatique)";
            [ru] = "?"
        };
        WhenCreatingNew = {
            [en] = "When creating new reminders:";
            [de] = "Beim Erstellen neuer Erinnerungen:";
            [fr] = "À la création de nouveaux rappels:";
            [ru] = "?"
        };
        WhatServer = {
            [en] = "Which server are you currently logged in on?";
            [de] = "Auf welchem Server bist du gerade angemeldet?";
            [fr] = "Sur quel serveur êtes-vous actuellement connecté?";
            [ru] = "?";
        };
		DetectServerName = {
            [en] = "Detect";
            [de] = "Ermitteln";
            [fr] = "Détecter";
            [ru] = "?"
        };
        DetectServerNameWidth = {
            [en] = 80;
            [de] = 80;
            [fr] = 80;
            [ru] = 80
        };
        ServerName = {
            [en] = "Server";
            [de] = "Server";
            [fr] = "Serveur";
            [ru] = "?";
        };
        ServerUnknown = {
            [en] = "Unknown";
            [de] = "Unbekannt";
            [fr] = "Inconnu";
            [ru] = "?";
        };
        WhatIsLocalTimeOffset = {
            [en] = "What is your local time difference from server time?";
            [de] = "Wie groß ist der Zeitunterschied zwischen deiner lokalen Uhrzeit und der Serverzeit?";
            [fr] = "Quelle est la différence de temps entre l'heure locale et l'heure du serveur ?";
            [ru] = "?"
        };
        OffsetHours = {
            [en] = "Offset (+/- hours)";
            [de] = "Ausgleichen (+/- Stunden)";
            [fr] = "Décalage (+/- heures)";
            [ru] = "?"
        };
        DetectServerTime = {
            [en] = "Detect";
            [de] = "Ermitteln";
            [fr] = "Détecter";
            [ru] = "?"
        };
        DetectServerTimeWidth = {
            [en] = 80;
            [de] = 80;
            [fr] = 80;
            [ru] = 80
        };
        AskBeforeDeleting = {
            [en] = "Ask “Are you sure?” before deleting";
            [de] = "Vor dem Löschen „Bist du sicher?“ fragen";
            [fr] = "Demandez: « Vous êtes sûr ? » avant d'effacer";
            [ru] = "?"
        };
        HideEmptyTabsWhenFiltering = {
            [en] = "Filter button hides empty tabs";
            [de] = "Filter-Schaltfläche blendet leere Registerkarten aus†";
            [fr] = "Le bouton de filtrage masque les onglets vides†";
            [ru] = "?"
        };
        UseNowForPastTimes = {
            [en] = "Denote all times in the past as “now”";
            [de] = "Alle Zeiten in der Vergangenheit als „jetzt“ bezeichnen";
            [fr] = "Désigner tous les temps passé comme « maintenant »";
            [ru] = "?"
        };
        DefaultCategory = {
            [en] = "Default category";
            [de] = "Standardkategorie";
            [fr] = "Catégorie par défaut";
            [ru] = "?"
        };
        DefaultTime = {
            [en] = "Default time";
            [de] = "Standardzeit";
            [fr] = "Délai par défaut";
            [ru] = "?"
        };
        WhenPostponingExpired = {
            [en] = "When postponing expired reminders:";
            [de] = "Beim Verschieben abgelaufener Erinnerungen:";
            [fr] = "Lorsqu'une alerte est repoussée:";
            [ru] = "?"
        };
        Appearance = {
            [en] = "Appearance";
            [de] = "Aussehen";
            [fr] = "Apparence";
            [ru] = "?"
        };
        HideWindowControls = {
            [en] = "Hide window border when mouse cursor is away";
            [de] = "Fensterrahmen ausblenden wenn der Mauszeiger ausserhalb ist";
            [fr] = "Cacher les bordures de la fenêtre lorsqu'elle n'est pas survolée";
            [ru] = "?"
        };
        MouseLeaveWindowOpacity = {
            [en] = "Make window transparent when mouse cursor is away:";
            [de] = "Fenster transparent anzeigen wenn der Mauszeiger ausserhalb ist:";
            [fr] = "Transparence de la fenêtre lorsque non survolée par la souris:";
            [ru] = "?"
        };
        Transparent = {
            [en] = "transparent";
            [de] = "transparent";
            [fr] = "transparent";
            [ru] = "?"
        };
        Opaque = {
            [en] = "opaque";
            [de] = "deckend";
            [fr] = "opaque";
            [ru] = "?"
        };
        IconSize = {
            [en] = "Icon size:";
            [de] = "Symbolgröße:";
            [fr] = "Taille de l'icône:";
            [ru] = "?"
        };
        Small = {
            [en] = "small";
            [de] = "klein";
            [fr] = "petit";
            [ru] = "?"
        };
        Large = {
            [en] = "large";
            [de] = "groß";
            [fr] = "grand";
            [ru] = "?"
        };
        MouseLeaveIconOpacity = {
            [en] = "Make icon transparent when mouse cursor is away:";
            [de] = "Symbol transparent darstellen wenn der Mauszeiger nicht darüber liegt:";
            [fr] = "Transparence de l’icône lorsque non survolé par la souris:";
            [ru] = "?"
        };
        IconAlwaysInFront = {
            [en] = "Always keep icon in front of UI windows";
            [de] = "Symbol immer vor Fenstern der Benutzeroberfläche halten";
            [fr] = "Toujours placer l'icône au premier plan";
            [ru] = "?"
        };
        MarqueeStyle = {
            [en] = "Selection style";
            [de] = "Auswahlstil";
            [fr] = "Style de sélection";
            [ru] = "?"
        };
        Ants = {
            [en] = "ants";
            [de] = "Ameisenlinie";
            [fr] = "pointillé";
            [ru] = "?"
        };
        SolidLine = {
            [en] = "solid line";
            [de] = "durchgezogene Linie";
            [fr] = "encadré";
            [ru] = "?"
        };
        ShowCascade = {
            [en] = "Generate bubble notifications";
            [de] = "Blasenbenachrichtigungen generieren";
            [fr] = "Générer des notifications bulle";
            [ru] = "?"
        };
        Categories = {
            [en] = "Categories";
            [de] = "Kategorien";
            [fr] = "Catégories";
            [ru] = "?"
        };
        ChangeCategoryColor = {
            [en] = "Change the color for this category";
            [de] = "Farbe für diese Kategorie ändern";
            [fr] = "Changer la couleur de cette catégorie";
            [ru] = "?"
        };
        DeleteCategory = {
            [en] = "Delete this category";
            [de] = "Diese Kategorie löschen";
            [fr] = "Supprimer cette catégorie";
            [ru] = "?"
        };
        CreateNewCategory = {
            [en] = "New Category";
            [de] = "Neue Kategorie";
            [fr] = "Ajouter une catégorie";
            [ru] = "?"
        };
        CreateNewCategoryWidth = {
            [en] = 120;
            [de] = 128;
            [fr] = 170;
            [ru] = 128
        };
    };
    TabTab = {
        TabName = {
            [en] = "Tab";
            [de] = "Reiter";
            [fr] = "Onglet";
            [ru] = "?"
        };
        ChooseTab = {
            [en] = "Options for tab";
            [de] = "Optionen für den Reiter";
            [fr] = "Options pour l'onglet";
            [ru] = "?"
        };
        General = {
            [en] = "General";
            [de] = "Allgemein";
            [fr] = "Général";
            [ru] = "?"
        };
        Rename = {
            [en] = "Rename";
            [de] = "Umbenennen";
            [fr] = "Renommer";
            [ru] = "?"
        };
        Color = {
            [en] = "Color...";
            [de] = "Farbe...";
            [fr] = "Couleur...";
            [ru] = "Цвет..."
        };
        Alerts = {
            [en] = "Notifications";
            [de] = "Benachrichtigungen";
            [fr] = "Notifications";
            [ru] = "?"
        };
        ShowPopupNotifications = {
            [en] = "Show popup notification when a reminder under this tab expires";
            [de] = "Blasenbenachrichtigung anzeigen wenn eine Erinnerung in diesem Reiter abläuft";
            [fr] = "Afficher la notification par popup à l'expiration du rappel";
            [ru] = "?"
        };
        UpdateIcon = {
            [en] = "Update the icon when a reminder under this tab expires";
            [de] = "Das Symbol erneuern wenn eine Erinnerung in diesem Reiter abläuft";
            [fr] = "Mettre à jour l'icône lorsqu'un rappel sous cet onglet expire";
            [ru] = "?"
        };
        OtherOptions = {
            [en] = "Other Options";
            [de] = "Weitere Optionen";
            [fr] = "Autres options";
            [ru] = "?"
        };
        OtherOptionsHow = {
            [en] = "For other options, right-click the tab's name in the main window.";
            [de] = "Rechts-Klick auf den Namen des Reiters im Hauptfenster, um weitere Optionen zu sehen.";
            [fr] = "Pour les autres options, cliquez avec le bouton droit sur le nom de l'onglet dans la fenêtre principale";
            [ru] = "?"
        }; -- also right-click the column names
    };
    CharacterTab = {
        TabName = {
            [en] = "Character";
            [de] = "Charakter";
            [fr] = "Personnage";
            [ru] = "?"
        };
        ChooseCharacter = {
            [en] = "Options for";
            [de] = "Optionen für";
            [fr] = "Modifier les réglages pour";
            [ru] = "?"
        };
        ForgetCharacter = {
            [en] = "Delete the settings for this character";
            [de] = "Einstellungen für diesen Charakter löschen";
            [fr] = "Supprimer les paramètres pour ce personnage";
            [ru] = "?";
        };
        StandardAutoReminders = {
            [en] = "Automatic Reminders";
            [de] = "Automatische Erinnerungen";
            [fr] = "Rappels automatiques";
            [ru] = "?"
        };
        ChannelNeededWarning = {
            [en] = "Note: In order for this feature to work, the „<channel>“ channel must be enabled in at least one tab of your Chat window.";
            [de] = "Hinweis: Damit diese Funktion funktioniert, muss der „<channel>“-Kanal in mindestens einem Reiter deines Chatfensters aktiviert sein.";
            [fr] = "Remarque : Pour que cette fonctionnalité fonctionne, le canal « <channel> » doit être activé dans au moins un onglet de ta fenêtre de chat.";
            [ru] = "Примечание: Для работы этой функции канал «<channel>» должен быть включен в как минимум одной вкладке твоего окна чата."
        };
        RaidLockRemindersEnabled = {
            [en] = "Create reminders for raid/chest locks";
            [de] = "Erinnerungen für Schlachtzug-/Lootsperren erstellen";
            [fr] = "Créer des rappels pour les verrous de raid/coffre";
            [ru] = "?"
        };
        RaidLockRemindersNotesEnabled = {
            [en] = "Record favoured completions in “Notes”";
            [de] = "Bevorzugte Abschlüsse in „Notizen“ aufzeichnen";
            [fr] = "Enregistrer les achèvements préférés dans « Notes »";
            [ru] = "Записывать предпочитаемые завершения в « Заметки »†";
        };
        CraftingRemindersEnabled = {
            [en] = "Create reminders for crafting cooldowns";
            [de] = "Erinnerungen für Handwerkscooldowns erstellen";
            [fr] = "Créer des rappels pour les temps de recharge d'artisanat";
            [ru] = "Создавать напоминания для кулдаунов крафта"
        };
        CraftingRemindersChannelNeeded = {
            [en] = "Loot (Self)";
            [de] = "Beute (Selbst)";
            [fr] = "Butin (Soi-même)";
            [ru] = "Трофеи (свои)"
        };
        TasksRemindersEnabled = {
            [en] = "Create reminders for daily “task” quests";
            [de] = "Erinnerungen für tägliche „Auftrag“ Aufgaben erstellen";
            [fr] = "Créer des rappels pour les quêtes quotidiennes de « tâches »";
            [ru] = "Создавать напоминания для ежедневных квестов на «задания»†"
        };
        TasksRemindersChannelNeeded = {
            [en] = "Quest";
            [de] = "Aufgabe";
            [fr] = "Quête";
            [ru] = "Задания";
        };
        CratesRemindersEnabled = {
            [en] = "Create reminders for ingredient crates";
            [de] = "Erinnerungen für Zutatenkisten erstellen";
            [fr] = "Créer des rappels pour les caisses d'ingrédients";
            [ru] = "Создавать напоминания для ящиков с ингредиентами†";
        };
        CratesRemindersChannelNeeded = {
            [en] = "Loot (Self)";
            [de] = "Beute (Selbst)";
            [fr] = "Butin (Soi-même)";
            [ru] = "Трофеи (свои)"
        };
        QuestsRemindersEnabled = {
            [en] = "Create reminders for repeatable quests";
            [de] = "Erinnerungen für wiederholbare Aufgaben erstellen";
            [fr] = "Créer des rappels pour les quêtes répétables";
            [ru] = "Создавать напоминания для повторяющихся квестов†"
        };
        QuestsRemindersChannelNeeded = {
            [en] = "Quest";
            [de] = "Aufgabe";
            [fr] = "Quête";
            [ru] = "Задания";
        };
        ChooseTab = {
            [en] = "under Tab";
            [de] = "unter Reiter";
            [fr] = "dans l’onglet";
            [ru] = "?"
        };
        ChooseCategory = {
            [en] = "in Category";
            [de] = "in Kategorie";
            [fr] = "leur attribuer la catégorie";
            [ru] = "?"
        };
        KnownLocks = {
            [en] = "Known Raid/Chest Locks";
            [de] = "Bekannte Schlachtzug-/Lootsperren";
            [fr] = "Raid/verouillage de coffre connues";
            [ru] = "?";
        };
        KnownRepeatableQuests = {
            [en] = "Known Repeatable Quests";
            [de] = "Bekannte wiederholbare Aufgaben";
            [fr] = "Quêtes répétables enrergistrées";
            [ru] = "?"
        };
        ForgetQuest = {
            [en] = "Forget this quest";
            [de] = "Diese Aufgabe vergessen";
            [fr] = "Oublier cette quête";
            [ru] = "?"
        };
        ForgetLock = {
            [en] = "Forget this lock";
            [de] = "Diese Sperre vergessen";
            [fr] = "Oublier ce verouillage";
            [ru] = "?"
        };
        EditQuest = {
            [en] = "Edit the settings related to this quest";
            [de] = "Diese Aufgabe betreffende Einstellungen anpassen";
            [fr] = "Modifier les réglages pour cette quête";
            [ru] = "?"
        };
        EditLock = {
            [en] = "Edit the settings related to this raid/chest lock";
            [de] = "Einstellungen, die sich auf diese Schlachtzug-/Lootsperre beziehen, anpassen";
            [fr] = "Modifier les paramètres liés à ce raid/verouillage de coffre";
            [ru] = "?"
        };
    };
};

-- Verbose help windows
text.Help = {};


-- Add translations to the global database (see Thurallor.Common.Utils.Locale.lua)
L:AddText(text);
